@@ -1050,7 +1050,28 @@ class DictSource:
         self.mapping = mapping
     
     def load(self) -> DFMConfig:
-        """Load configuration from dictionary."""
+        """Load configuration from dictionary.
+        
+        If the dictionary is partial (e.g., only max_iter, threshold),
+        it will be merged with a minimal default config.
+        """
+        # Check if this is a partial config (missing series or blocks)
+        has_series = 'series' in self.mapping and self.mapping['series']
+        has_blocks = 'blocks' in self.mapping and self.mapping['blocks']
+        
+        if not has_series or not has_blocks:
+            # This is a partial config - create a minimal default and merge
+            minimal_default = {
+                'series': [],
+                'blocks': {},
+                'clock': 'm',
+                'max_iter': 5000,
+                'threshold': 1e-5
+            }
+            # Merge: mapping takes precedence
+            merged = {**minimal_default, **self.mapping}
+            return DFMConfig.from_dict(merged)
+        
         return DFMConfig.from_dict(self.mapping)
 
 
@@ -1142,10 +1163,36 @@ class MergedConfigSource:
         from dataclasses import fields
         
         base_cfg = self.base.load()
-        override_cfg = self.override.load()
+        
+        # Check if override is a partial config (DictSource with partial dict)
+        override_is_partial = False
+        if isinstance(self.override, DictSource):
+            has_series = 'series' in self.override.mapping and self.override.mapping['series']
+            has_blocks = 'blocks' in self.override.mapping and self.override.mapping['blocks']
+            override_is_partial = not (has_series and has_blocks)
+        
+        if override_is_partial:
+            # Handle partial override: merge fields directly without loading full DFMConfig
+            override_dict = self.override.mapping
+            override_cfg = base_cfg  # Use base as template
+        else:
+            override_cfg = self.override.load()
         
         # Merge blocks: override takes precedence
-        merged_blocks = {**base_cfg.blocks, **override_cfg.blocks}
+        if override_is_partial and 'blocks' in override_dict:
+            # Merge block dicts
+            merged_blocks = {**base_cfg.blocks, **override_dict['blocks']}
+        else:
+            merged_blocks = {**base_cfg.blocks, **override_cfg.blocks}
+        
+        # Use override's series if provided and non-empty, otherwise use base's series
+        if override_is_partial:
+            if 'series' in override_dict and override_dict['series']:
+                merged_series = override_dict['series']
+            else:
+                merged_series = base_cfg.series
+        else:
+            merged_series = override_cfg.series if (override_cfg.series and len(override_cfg.series) > 0) else base_cfg.series
         
         # Get all config fields (excluding derived/computed fields)
         excluded_fields = {'series', 'blocks', 'block_names', 'factors_per_block', '_cached_blocks'}
@@ -1155,11 +1202,29 @@ class MergedConfigSource:
             if field.name not in excluded_fields
         }
         
-        # Create merged config: base settings + override series + merged blocks
+        # Override settings from override_cfg or override_dict
+        if override_is_partial:
+            override_settings = {
+                field.name: override_dict.get(field.name, getattr(base_cfg, field.name))
+                for field in fields(DFMConfig)
+                if field.name not in excluded_fields
+            }
+        else:
+            override_settings = {
+                field.name: getattr(override_cfg, field.name)
+                for field in fields(DFMConfig)
+                if field.name not in excluded_fields
+                and hasattr(override_cfg, field.name)
+            }
+        
+        # Merge settings: base + override (override takes precedence)
+        merged_settings = {**base_settings, **override_settings}
+        
+        # Create merged config: merged settings + merged series + merged blocks
         return DFMConfig(
-            series=override_cfg.series,  # Override series
-            blocks=merged_blocks,  # Merged blocks
-            **base_settings  # All other settings from base
+            series=merged_series,
+            blocks=merged_blocks,
+            **merged_settings
         )
 
 
